@@ -81,12 +81,12 @@ def upload_file(hosts, filename, branch, auth, hashalgo='sha512',
 
     """
     if compress:
-        tf = tempfile.NamedTemporaryFile("wb")
-        with gzip.GzipFile(filename, "wb", fileobj=tf) as gz:
+        file = tempfile.NamedTemporaryFile("w+b")
+        with gzip.GzipFile(filename, "wb", fileobj=file) as gz:
             with open(filename, "rb") as f:
                 gz.writelines(f)
-        tf.flush()
-        file = open(tf.name, "rb")
+        file.flush()
+        file.seek(0)
     else:
         file = open(filename, "rb")
     if blobhash is None:
@@ -168,7 +168,7 @@ def post_file(host, auth, file, filename, branch, hashalgo, blobhash,
     data_dict = dict(blob=(os.path.basename(filename), file))
     meta_dict = dict(branch=branch)
     if compressed:
-        meta_dict[compressed] = compressed
+        meta_dict['compressed'] = compressed
 
     log.debug("Uploading file to %s ...", url)
     # make the request call to blob server
